@@ -80,7 +80,6 @@ import com.openexchange.mail.mime.MimeSessionPropertyNames;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.session.Session;
-import com.sun.mail.imap.DefaultFolder;
 import com.sun.mail.imap.IMAPFolder;
 import com.sun.mail.imap.IMAPMessage;
 import com.sun.mail.imap.IMAPStore;
@@ -112,7 +111,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
             this.error = e;
             this.stamp = System.currentTimeMillis();
         }
-    }
+    } // End of class FailFastError
 
     private static final ConcurrentMap<String, FailFastError> FAIL_FAST = new NonBlockingHashMap<String, FailFastError>();
 
@@ -140,6 +139,9 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
      * @throws MessagingException If such a fail-fast error exists and has not elapsed, yet
      */
     public static void checkFailFast(final IMAPStore imapStore, final String fullName) throws MessagingException {
+        if (null == imapStore || null == fullName) {
+            return;
+        }
         final String key = fullName + '@' + imapStore.toString();
         final FailFastError failFastError = FAIL_FAST.get(key);
         if (null == failFastError) {
@@ -154,26 +156,17 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
     /*
      * Fields
      */
+
     protected final AccessedIMAPStore imapStore;
-
     protected final Session session;
-
     protected final int accountId;
-
     protected final Context ctx;
-
     protected final IMAPAccess imapAccess;
-
     protected final UserSettingMail usm;
-
     protected final IMAPConfig imapConfig;
-
     protected final ACLExtension aclExtension;
-
     protected IMAPFolder imapFolder;
-
     protected final Set<IMAPFolder> otherFolders;
-
     protected int holdsMessages = -1;
 
     /**
@@ -358,13 +351,9 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
             closeOtherFolders();
         }
         final boolean isDefaultFolder = DEFAULT_FOLDER_ID.equals(fullName);
-        final boolean isIdenticalFolder;
-        if (isDefaultFolder) {
-            isIdenticalFolder = (imapFolder == null ? false : 0 == imapFolder.getFullName().length());
-        } else {
-            isIdenticalFolder = (imapFolder == null ? false : fullName.equals(imapFolder.getFullName()));
-        }
         if (imapFolder != null) {
+            final String imapFolderFullname = imapFolder.getFullName();
+            final boolean isIdenticalFolder = isDefaultFolder ? 0 == imapFolderFullname.length() : fullName.equals(imapFolderFullname);
             /*
              * Obtain folder lock once to avoid multiple acquire/releases when invoking folder's getXXX() methods
              */
@@ -406,7 +395,6 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                  * Folder is closed here
                  */
                 if (isIdenticalFolder) {
-                    final String imapFolderFullname = imapFolder.getFullName();
                     try {
                         if ((imapFolder.getType() & Folder.HOLDS_MESSAGES) == 0) { // NoSelect
                             throw IMAPException.create(
@@ -438,7 +426,7 @@ public abstract class IMAPFolderWorker extends MailMessageStorageLong {
                     openFolder(desiredMode, imapFolder);
                     return imapFolder;
                 }
-            }
+            } // End of synchronized
         }
         final IMAPFolder retval = (isDefaultFolder ? (IMAPFolder) imapStore.getDefaultFolder() : (IMAPFolder) imapStore.getFolder(fullName));
         if (imapStore.notifyRecent() && (desiredMode == Folder.READ_WRITE)) {
