@@ -73,6 +73,7 @@ import javax.mail.internet.InternetAddress;
 import javax.mail.internet.InternetHeaders;
 import javax.mail.internet.MailDateFormat;
 import com.openexchange.exception.OXException;
+import com.openexchange.java.StringAllocator;
 import com.openexchange.mail.dataobjects.IDMailMessage;
 import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.mime.ContentType;
@@ -218,7 +219,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
 
     @Override
     protected String getDebugInfo(final int argsIndex) {
-        final StringBuilder sb = new StringBuilder(command.length() + 64);
+        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(command.length() + 64);
         if (uid) {
             sb.append("UID ");
         }
@@ -250,7 +251,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
 
     @Override
     protected String getCommand(final int argsIndex) {
-        final StringBuilder sb = new StringBuilder(args[argsIndex].length() + 64);
+        final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator(args[argsIndex].length() + 64);
         if (uid) {
             sb.append("UID ");
         }
@@ -290,7 +291,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
                 server = server.substring(pos);
             }
             final MessagingException e =
-                new MessagingException(new StringBuilder(32).append("Expected ").append(length).append(" FETCH responses but got ").append(
+                new MessagingException(new com.openexchange.java.StringAllocator(32).append("Expected ").append(length).append(" FETCH responses but got ").append(
                     index).append(" from IMAP folder \"").append(imapFolder.getFullName()).append("\" on server \"").append(server).append(
                     "\".").toString());
             LOG.warn(e.getMessage(), e);
@@ -302,7 +303,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         try {
             return handleMessage(imapFolder.getMessage(seqNum));
         } catch (final Exception e) {
-            LOG.warn(new StringBuilder(128).append("Message #").append(seqNum).append(" discarded: ").append(e.getMessage()).toString(), e);
+            LOG.warn(new com.openexchange.java.StringAllocator(128).append("Message #").append(seqNum).append(" discarded: ").append(e.getMessage()).toString(), e);
             return null;
         }
     }
@@ -311,7 +312,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         try {
             return handleMessage(imapFolder.getMessageByUID(uid));
         } catch (final Exception e) {
-            LOG.warn(new StringBuilder(128).append("Message uid=").append(uid).append(" discarded: ").append(e.getMessage()).toString(), e);
+            LOG.warn(new com.openexchange.java.StringAllocator(128).append("Message uid=").append(uid).append(" discarded: ").append(e.getMessage()).toString(), e);
             return null;
         }
     }
@@ -329,7 +330,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         } catch (final Exception e) {
             if (WARN) {
                 LOG.warn(
-                    new StringBuilder(128).append("Message #").append(message.getMessageNumber()).append(" discarded: ").append(
+                    new com.openexchange.java.StringAllocator(128).append("Message #").append(message.getMessageNumber()).append(" discarded: ").append(
                         e.getMessage()).toString(),
                     e);
             }
@@ -374,7 +375,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
             if (WARN) {
                 final OXException imapExc = MimeMailException.handleMessagingException(e);
                 LOG.warn(
-                    new StringBuilder(128).append("Message #").append(seqNum).append(" discarded: ").append(imapExc.getMessage()).toString(),
+                    new com.openexchange.java.StringAllocator(128).append("Message #").append(seqNum).append(" discarded: ").append(imapExc.getMessage()).toString(),
                     imapExc);
             }
             error = true;
@@ -385,7 +386,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
              */
             if (WARN) {
                 LOG.warn(
-                    new StringBuilder(128).append("Message #").append(seqNum).append(" discarded: ").append(e.getMessage()).toString(),
+                    new com.openexchange.java.StringAllocator(128).append("Message #").append(seqNum).append(" discarded: ").append(e.getMessage()).toString(),
                     e);
             }
             error = true;
@@ -399,7 +400,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
 
     /**
      * Converts given FETCH response to an appropriate {@link MailMessage} instance.
-     * 
+     *
      * @param fetchResponse The FETCH response to handle
      * @param fullName The full name of associated folder
      * @param separator The separator character
@@ -450,7 +451,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         }
         return mail;
     }
-    
+
     private static FetchItemHandler getItemHandlerByItem(final Item item) {
         if ((item instanceof RFC822DATA) || (item instanceof BODY)) {
             return HEADER_ITEM_HANDLER;
@@ -579,6 +580,13 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
                         }
                     }
                 });
+                put(MessageHeaders.HDR_REFERENCES, new HeaderHandler() {
+
+                    @Override
+                    public void handle(final Header hdr, final IDMailMessage mailMessage) throws OXException {
+                        mailMessage.setReferences(hdr.getValue());
+                    }
+                });
             }
         };
 
@@ -601,7 +609,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
                 h = new InternetHeaders();
                 if (null == headerStream) {
                     if (logger.isDebugEnabled()) {
-                        logger.debug(new StringBuilder(32).append("Cannot retrieve headers from message #").append(msg.getSeqnum()).append(
+                        logger.debug(new com.openexchange.java.StringAllocator(32).append("Cannot retrieve headers from message #").append(msg.getSeqnum()).append(
                             " in folder ").append(msg.getFolder()).toString());
                     }
                 } else {
@@ -822,8 +830,8 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
                     }
                 }
             }
-            msg.addHeader("In-Reply-To", env.inReplyTo);
-            msg.addHeader("Message-Id", env.messageId);
+            msg.setHeader("In-Reply-To", env.inReplyTo);
+            msg.setHeader("Message-Id", env.messageId);
             msg.setSubject(MimeMessageUtility.decodeEnvelopeSubject(env.subject));
             msg.setSentDate(env.date);
         }
@@ -901,7 +909,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
         @Override
         public void handleItem(final Item item, final IDMailMessage msg, final org.apache.commons.logging.Log logger) throws OXException {
             final BODYSTRUCTURE bs = (BODYSTRUCTURE) item;
-            final StringBuilder sb = new StringBuilder();
+            final com.openexchange.java.StringAllocator sb = new com.openexchange.java.StringAllocator();
             sb.append(bs.type).append('/').append(bs.subtype);
             if (bs.cParams != null) {
                 sb.append(bs.cParams);
@@ -986,7 +994,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
 
         /**
          * Initializes a new {@link FetchItem}.
-         * 
+         *
          * @param name The name
          */
         protected FetchItem(String name) {
@@ -999,40 +1007,40 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
      * This is the Envelope item. Despite of JavaMail's ENVELOPE item, this item does not include INTERNALDATE nor RFC822.SIZE; it solely
      * consists of the ENVELOPE.
      * <p>
-     * The Envelope is an aggregration of the common attributes of a Message. Implementations should include the following attributes: From,
+     * The Envelope is an aggregation of the common attributes of a Message. Implementations should include the following attributes: From,
      * To, Cc, Bcc, ReplyTo, Subject and Date. More items may be included as well.
      */
     public static final FetchProfile.Item ENVELOPE_ONLY = new FetchItem("ENVELOPE_ONLY");
 
     /**
      * Turns given fetch profile into FETCH items to craft a FETCH command.
-     * 
+     *
      * @param isRev1 Whether IMAP protocol is revision 1 or not
      * @param fp The fetch profile to convert
      * @param loadBody <code>true</code> if message body should be loaded; otherwise <code>false</code>
      * @return The FETCH items to craft a FETCH command
      */
     public static String getFetchCommand(final boolean isRev1, final FetchProfile fp, final boolean loadBody) {
-        final StringBuilder command = new StringBuilder(128);
-        final boolean envelope;
+        final StringAllocator command = new StringAllocator(128);
+        final boolean sizeIncluded;
         if (fp.contains(FetchProfile.Item.ENVELOPE)) {
             if (loadBody) {
                 command.append("INTERNALDATE");
-                envelope = false;
+                sizeIncluded = false;
             } else {
                 command.append("ENVELOPE INTERNALDATE RFC822.SIZE");
-                envelope = true;
+                sizeIncluded = true;
             }
         } else if (fp.contains(ENVELOPE_ONLY)) {
             if (loadBody) {
                 command.append("INTERNALDATE");
             } else {
-                command.append("ENVELOPE");
+                command.append("ENVELOPE INTERNALDATE");
             }
-            envelope = false;
+            sizeIncluded = false;
         } else {
             command.append("INTERNALDATE");
-            envelope = false;
+            sizeIncluded = false;
         }
         if (fp.contains(FetchProfile.Item.FLAGS)) {
             command.append(" FLAGS");
@@ -1052,7 +1060,7 @@ public final class MailMessageFetchIMAPCommand extends AbstractIMAPCommand<MailM
                 command.append(" RFC822.HEADER");
             }
         }
-        if (!envelope && fp.contains(IMAPFolder.FetchProfileItem.SIZE)) {
+        if (!sizeIncluded && fp.contains(IMAPFolder.FetchProfileItem.SIZE)) {
             command.append(" RFC822.SIZE");
         }
         /*
